---
to: package.json
force: true # this is because mostly, people init into existing folders is safe
---
{
  "name": "<%= repoName %>",
  "description": "<%= repoDescription %>",
  "version": "1.0.0",
  "lint-staged": {
    "*.ts": [
      "yarn run lint"
    ]
  },
  "scripts": {
    <% if( language === 'Typescript' ) {-%>
"build": "rm -rf ./build/dist/ && tsc --outDir build/dist/",
    "build:local": "rm -rf ./build/local/ && tsc --outDir build/local/",
    <% } -%>
"start": "node src/app.js --enable-source-maps",
    "start:local": "nodemon ./build/local/src/app.js --enable-source-maps",
    "test:unit": "jest --collectCoverage --passWithNoTests --roots ./tests/unit",
    "test:integration": "APP_ENV=integration jest --collectCoverage --detectOpenHandles --forceExit --roots ./tests/integration",
    "watch:local": "rm -rf ./build/local/ && tsc --watch --outDir build/local/",
    "lint": "eslint --config .eslintrc.json --ext ts src tests --fix",
    "pre-commit": "lint-staged",
    "env:up": "docker-compose up -d --build",
    "env:down": "docker-compose down",
    "prepare": "husky install",
    "init:repo": "npx hygen init repo"
  },
  "author": "Sertis Co.Ltd. - Software Engineering",
  "license": "MIT",
  "homepage": "https://gitlab.com/sertiscorp/dev/7-11-chat/backend/user-service#readme",
  "devDependencies": {
    "@types/jest": "^27.4.1",
    "@types/jsonwebtoken": "^8.5.8",
    "@types/luxon": "^3.0.0",
    "@types/module-alias": "^2.0.1",
    "@types/superagent": "^4.1.15",
    "@typescript-eslint/eslint-plugin": "^4.22.0",
    "@typescript-eslint/parser": "^4.22.0",
    "eslint": "^7.23.0",
    "eslint-config-prettier": "^8.1.0",
    "eslint-import-resolver-typescript": "^2.4.0",
    "eslint-plugin-import": "^2.23.4",
    "husky": "^7.0.4",
    "jest": "^27.5.1",
    "jest-junit": "^13.0.0",
    "jest-node-exports-resolver": "^1.1.5",
    "lint-staged": "^12.3.4",
    "nodemon": "^2.0.15",
    "prettier": "^2.3.2",
    "superagent": "^7.1.1",
    <% if( language === 'Typescript' ) {-%>
"ts-jest": "^27.1.3",
    "typescript": "^4.6.2"
    <% } -%>
  },
  "dependencies": {
    "@sertis-chat-commerce/ts-toolkit": "^1.2.5-a",
    "agentkeepalive": "^4.2.1",
    "joi": "^17.6.0",
    "jsonwebtoken": "^8.5.1",
    "luxon": "^3.0.1",
    "module-alias": "^2.2.2"
  },
  "volta": {
    "node": "14.20.0"
  }
}
